# fimama - Fictional Map Maker

This is a hobby project which aims to create a map maker program (not a web
app) for fictional (not just fantasy) worlds. 

I'll start with a Voronoi cell based heightmap and see how much I can be
bothered to work on this.

If things do progress I do have the following aims:
* The [Changelog](docs/Changelog.markdown) includes some more specific
  potential features
* I have more ideas than are listed there, but time is limited.

Some general principles:
* The project will [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).
* The project will use [semantic version numbering](https://semver.org/).
* The project will aim for pythonic code and good documentation.
* Keep backwards compatibility so that old maps should mostly be openable by
  later versions.
* Make most features editable, and make most features lockable when
  regenerating random features.
* Tests will be written as well but instead of code coverage, the priority is
  on integration tests.

What I wont most likely do:
* I do not intend to write any plate tectonics, but will be happy to integrate
  them if somebody else writes the code.

If you want to contribute, please get in touch.
